<?php
/***********
*
* Tweets Module Plus
* @version 4.3, Abril/2012 15/04/2012
* @author Fernando Soares ( www.fernandosoares.com.br )
* @package Joomla 1.5 ~ 2.5
* @copyright Copyright (C) 2009-2012 Fernando Soares.
* @license http://www.gnu.org/licenses/gpl-3.0.html
*
* Based on original version 2.2 (04-03-2009) from
*          Van Eldijk Studio's (components@vaneldijk.nl)
*          http://extensions.vaneldijk.nl
*          Copyright 2009 Van Eldijk Studio's
*          License at http://www.gnu.org/licenses/gpl-3.0.html
* 
************/
defined( '_JEXEC' ) or die( 'Restricted access' );

class modTweetsHelper {
	var $tweets = '';
	var $format = false;
	var $layout = 'default';
	var $errormessage = '';
	
	/**
	* The class constructor
	* 
	* The Tweets module Helper constructor
	* 
	* @access public
	* @param object $params The Joomla! parameter object
	* @return object The ModTweetsHelper object
	*/
	function modTweetsHelper( $params ) {
		if( $this->_checkCompatibility() ) {
			$this->format = $this->_checkFormat();
			if( $this->format ) {
				if( $params->get( 'enable-cache' ) === '1' ) {
					$cache =& JFactory::getCache();
					$cache->setCaching( true );
					$cache->setLifeTime( $params->get( 'cache-time', 30 ) * 60 );
					$this->tweets = $cache->get( array( $this, 'getTweets' ), array( $params ) );
				} else {
					$this->tweets = $this->getTweets( $params );
				}

				if( !$this->tweets ) {
					$this->layout = 'error';
				}
			} else {
				$this->layout = 'error';
				$this->errormessage = JText::_( 'MOD_TWEETS_ERROR_XML_JSON' );
			}
		} else {
			$this->layout = 'error';
			$this->errormessage = JText::_( 'MOD_TWEETS_ERROR_PHP_VERSION' );
		}
		return $this;
	}
	
	/**
	* 
	* Get the latest statuses from Twitter
	* 
	* @access public
	* @param object $params The Joomla! parameter object
	* @return mixed Returns false on failure, object on success
	*/
	function getTweets( $params ) {
		$count = intval( $params->get( 'count' ) );
		if( $count === 0 ) {
			$count = 5;
		} elseif( $count > 200 ) {
			$count = 200;
		}
		$this->userTimeLine( $params->get( 'username' ), $count );
		if( $this->output && $this->status == '200' ) {
			switch( $this->format ) {
				default:
				case 'xml':
					return $this->_decodeXML( $this->output );
					break;
				
				case 'json':
					return $this->_decodeJSON( $this->output );
					break;
			}
		} else {
			$this->errormessage = JText::_( 'MOD_TWEETS_ERROR_SERVER_RESPONSE' ) .' '. $this->status;
			return false;
		}
	}
	
	/**
	* 
	* Decodes the XML string returned from the Twitter class
	* 
	* @access private
	* @param mixed $output The output string returned by the Twitter class
	* @return array Returns an array of Twitter statuses
	*/
	function _decodeXML( $output ) {
		$statuses = array();
		$xml = simplexml_load_string( $output );
		foreach( $xml as $status ) {
			$statuses[] = $status;
		}
		return $statuses;
	}
	
	/**
	* 
	* Decodes the JSON string returned from the Twitter class
	* 
	* @access private
	* @param mixed $output The output string returned by the Twitter class
	* @return array Returns an array of Twitter statuses
	*/
	function _decodeJSON( $output ) {
		return json_decode( $output );
	}
	
	/**
	* Select either JSON or XML format
	* 
	* Check whether there is JSON support or XML support and return the format
	* 
	* @access private
	* @return string Return lowercase name of format
	*/
	function _checkFormat() {
		if( function_exists( 'json_decode' ) ) {
			return 'json';
		} elseif( function_exists( 'simplexml_load_string' ) ) {
			return 'xml';
		}
		return false;
	}
	
	/**
	* Check for PHP Compatibility
	* 
	* Checks if the PHP version on the server is higher than 5
	* 
	* @access private
	* @return boolean Returns false on failure, true on succes
	*/
	function _checkCompatibility() {
		return version_compare( PHP_VERSION, '5.0.0', '>' );
	}
	
	/**
	* 
	* Get the Twitter timeline for the user. 
	*
	* @access private
	*/
	function userTimeLine( $username, $count ) {
		$url = 'http://api.twitter.com/1/statuses/user_timeline/'. $username . '.' . $this->format . '?count=' . $count;

		$handle = curl_init();
		curl_setopt( $handle, CURLOPT_URL, $url );
		curl_setopt( $handle, CURLOPT_RETURNTRANSFER, true );				
		
		$this->output = curl_exec( $handle );
		$this->status = curl_getinfo( $handle, CURLINFO_HTTP_CODE );
		curl_close( $handle );
	}
}
?>